@@ -83,7 +83,7 @@ public class SAMLSessionInspector implements SessionInspectorService {
     @Override
     public Reply onSessionHit(Session session, HttpServletRequest request, HttpServletResponse response) throws OXException {
         Object parameter = session.getParameter(SAMLSessionParameters.SESSION_NOT_ON_OR_AFTER);
-        if (parameter != null && parameter instanceof String) {
+        if (parameter instanceof String) {
             try {
                 long notOnOrAfter = Long.parseLong((String) parameter);
                 if (System.currentTimeMillis() >= notOnOrAfter) {
@@ -95,17 +95,17 @@ public class SAMLSessionInspector implements SessionInspectorService {
             }
         }
 
-        return Reply.CONTINUE;
+        return Reply.NEUTRAL;
     }
 
     @Override
     public Reply onSessionMiss(String sessionId, HttpServletRequest request, HttpServletResponse response) throws OXException {
-        return Reply.CONTINUE;
+        return Reply.NEUTRAL;
     }
 
     @Override
     public Reply onAutoLoginFailed(Reason reason, HttpServletRequest request, HttpServletResponse response) throws OXException {
-        return Reply.CONTINUE;
+        return Reply.NEUTRAL;
     }
 
 }
